Header menu logo Partas.GitNet

BuildHelpers Module

Nested modules

Modules Description

CrackedProject

XElement

Type extensions

Type extension Description

this.RevertVersionProjects

Full Usage: this.RevertVersionProjects

Parameters:
    () : unit

Reverts all the .fsproj file changes saved to the disposal cache.

Extended Type: GitNetRuntime

() : unit

this.VersionProject

Full Usage: this.VersionProject

Parameters:
    project : CrackedProject - The project to act on.
    version : SemVersion - The version to apply.
    ?stageFile : bool - Whether to stage the file after writing. Default is false.
    ?cacheDisposal : bool - Whether to cache a reverse function to run on calling the disposal cache functions. Default is true

Applies a version to the given project's .fsproj file. Is not related to tags. Will stage the file if stageFile is true.

Extended Type: GitNetRuntime

project : CrackedProject

The project to act on.

version : SemVersion

The version to apply.

?stageFile : bool

Whether to stage the file after writing. Default is false.

?cacheDisposal : bool

Whether to cache a reverse function to run on calling the disposal cache functions. Default is true

this.VersionProjects

Full Usage: this.VersionProjects

Parameters:
    mapping : IDictionary<string, SepochSemver> - The map of project scopes to versions.
    ?stageFile : bool - Whether to stage the files after writing. Default is false
    ?cacheDisposal : bool - Whether to save the undo action into the Disposal cache. Default is true

Applies the given dictionary of scopes and versions to the relevant project .fsproj files. Will stage the files if stageFile is true.

Extended Type: GitNetRuntime

mapping : IDictionary<string, SepochSemver>

The map of project scopes to versions.

?stageFile : bool

Whether to stage the files after writing. Default is false

?cacheDisposal : bool

Whether to save the undo action into the Disposal cache. Default is true

Type something to start searching.