Header menu logo Partas.GitNet

Config Module

Computation Expressions for configuring GitNet

Types and nested modules

Type/Module Description

CommitBumpTypeMappingBuilder (Module)

CommitGroupBuilder (Module)

CommitIgnoreFooterParts (Module)

Internal CE use only

GitNetConfigBuilder (Module)

BumpConfigBuilder

CommitBumpMatcherBuilderBase<'T>

CommitBumpTypeMappingBuilder (Type)

CommitGroupBuilder (Type)

CommitIgnoreBuilder

CommitIgnoreFooterBuilder

CommitIgnoreFooterParts (Type)

Internal CE use only

GitNetConfigBuilder (Type)

GroupMatcherBuilder

MajorCommitBumpMatcherBuilder

MinorCommitBumpMatcherBuilder

OutputConfigBuilder

PatchCommitBumpMatcherBuilder

ProjectConfigBuilder

Functions and values

Function or value Description

bumpConfig

Full Usage: bumpConfig

Returns: BumpConfigBuilder

Computation Expression to build a BumpConfig record.

Returns: BumpConfigBuilder

commitBumpMatcher

Full Usage: commitBumpMatcher

Returns: CommitBumpTypeMappingBuilder

Computation Expression to build bump mappings for commit messages. Use the epoch custom operation in cooperation with the minors, patches and majors CE's.

Returns: CommitBumpTypeMappingBuilder

commitGroup title

Full Usage: commitGroup title

Parameters:
    title : string

Returns: CommitGroupBuilder

Computation Expression to build a CommitGroup record.

title : string
Returns: CommitGroupBuilder

footer

Full Usage: footer

Returns: CommitIgnoreFooterBuilder

Computation Expression to build a footer key or key value pair. Used with ignoreCommits, groupMatcher and others.

Returns: CommitIgnoreFooterBuilder

gitnetConfig

Full Usage: gitnetConfig

Returns: GitNetConfigBuilder

Computation Expression to build a GitNetConfig record.

Returns: GitNetConfigBuilder

groupMatcher group

Full Usage: groupMatcher group

Parameters:
Returns: GroupMatcherBuilder

Computation Expression to build a GroupMatcher, which is used to determine which commits belong to which group.

group : CommitGroup
Returns: GroupMatcherBuilder

ignoreCommits

Full Usage: ignoreCommits

Returns: CommitIgnoreBuilder

Computation Expression to build a list of IgnoreCommit settings.

Returns: CommitIgnoreBuilder
Example

 {
     CommitConfig.Ignore =
         ignoreCommits {
             skipci
             tag "v1.0.0"
             footer {
                 key "BREAKING CHANGE"
             }
         }
         // The CE produces a list of IgnoreCommit DUs
 }
1. Skips commits with the [skipci] header.
2. Skips commits for the tag v1.0.0.
3. Skips commits with a footer key of "BREAKING CHANGE".

majors

Full Usage: majors

Returns: MajorCommitBumpMatcherBuilder

Computation Expression to build bump mappings for major bumps

Returns: MajorCommitBumpMatcherBuilder

minors

Full Usage: minors

Returns: MinorCommitBumpMatcherBuilder

Computation Expression to build bump mappings for minor bumps

Returns: MinorCommitBumpMatcherBuilder

outputConfig

Full Usage: outputConfig

Returns: OutputConfigBuilder

Computation Expression to build the OutputConfig record.

Returns: OutputConfigBuilder

patches

Full Usage: patches

Returns: PatchCommitBumpMatcherBuilder

Computation Expression to build bump mappings for patch bumps

Returns: PatchCommitBumpMatcherBuilder

projectConfig

Full Usage: projectConfig

Returns: ProjectConfigBuilder

Computation Expression to build a ProjectConfig record.

Returns: ProjectConfigBuilder

Type something to start searching.