Header menu logo Partas.GitNet

CommitIgnoreFooterBuilder Type

Constructors

Constructor Description

CommitIgnoreFooterBuilder()

Full Usage: CommitIgnoreFooterBuilder()

Returns: CommitIgnoreFooterBuilder

Instance members

Instance member Description

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterParts

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterParts

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterParts

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterParts

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterValue

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterKey

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterValue

this.Combine

Full Usage: this.Combine

Parameters:
Returns: CommitIgnoreFooterKey

this.Delay

Full Usage: this.Delay

Parameters:
    value : unit -> 'a

Returns: 'a
Modifiers: inline
Type parameters: 'a
value : unit -> 'a
Returns: 'a

this.For

Full Usage: this.For

Parameters:
Returns: CommitIgnoreFooterParts
Modifiers: inline

this.For

Full Usage: this.For

Parameters:
Returns: CommitIgnoreFooterParts
Modifiers: inline

key value

Full Usage: key value

Parameters:
    value : string

Returns: CommitIgnoreFooterKey
Modifiers: inline

Ignore commits with the footer key equal to the value

value : string
Returns: CommitIgnoreFooterKey

key value

Full Usage: key value

Parameters:
    value : string

Returns: CommitIgnoreFooterParts
Modifiers: inline

Ignore commits with the footer key equal to the value

value : string
Returns: CommitIgnoreFooterParts

this.Run

Full Usage: this.Run

Parameters:
Returns: IgnoreCommit
Modifiers: inline

this.Run

Full Usage: this.Run

Parameters:
Returns: IgnoreCommit
Modifiers: inline

value value

Full Usage: value value

Parameters:
    value : string

Returns: CommitIgnoreFooterParts
Modifiers: inline

Ignore commits with the footer value equal to the input

value : string
Returns: CommitIgnoreFooterParts

value value

Full Usage: value value

Parameters:
    value : string

Returns: CommitIgnoreFooterValue
Modifiers: inline

Ignore commits with the footer value equal to the input

value : string
Returns: CommitIgnoreFooterValue

this.Yield

Full Usage: this.Yield

Parameters:
    value : string

Returns: CommitIgnoreFooterKey
Modifiers: inline
value : string
Returns: CommitIgnoreFooterKey

this.Yield

Full Usage: this.Yield

Parameters:
    () : unit

() : unit

this.Yield

Full Usage: this.Yield

Parameters:
Returns: CommitIgnoreFooterParts

this.Yield

Full Usage: this.Yield

Parameters:
Returns: CommitIgnoreFooterValue

this.Yield

Full Usage: this.Yield

Parameters:
Returns: CommitIgnoreFooterKey

this.Zero

Full Usage: this.Zero

Type something to start searching.