Header menu logo Partas.GitNet

FSharpNameResolution Type

Union cases

Union case Description

Auto

Full Usage: Auto

Title > FileName

The scope is derived from the title of the project if present; otherwise, the file name is used.

Directory

Full Usage: Directory

The directory of a project is used to derive the scope name.

The string mapping to the scope name still utilises the configured method. The default will split by . and take the last part.

Example

 root
 
     
Scope name: Project

FileName

Full Usage: FileName

The file name is used to derive the scope name

The string mapping to the scope name still utilises the configured method. The default will split by . and take the last part.

Example

 root
 
     
Scope name: Project1

Title

Full Usage: Title

The title is used to derive the scope name. Projects without a title will be ignored.

The string mapping to the scope name still utilises the configured method. The default will split by . and take the last part.

Example

 root
 
     
 // ProjectXX.fsproj
 Project1
Scope name: Project1

Instance members

Instance member Description

this.IsAuto

Full Usage: this.IsAuto

Returns: bool
Returns: bool

this.IsDirectory

Full Usage: this.IsDirectory

Returns: bool
Returns: bool

this.IsFileName

Full Usage: this.IsFileName

Returns: bool
Returns: bool

this.IsTitle

Full Usage: this.IsTitle

Returns: bool
Returns: bool

Type something to start searching.