Header menu logo Partas.GitNet

RunExtensions Module

Types

Type Description

RuntimeOutput

Type extensions

Type extension Description

this.DryRun

Full Usage: this.DryRun

Parameters:
    () : unit

Returns: RuntimeOutput

Extended Type: GitNetRuntime

() : unit
Returns: RuntimeOutput

this.Run

Full Usage: this.Run

Parameters:
    ?username : string - Git username
    ?email : string - Git email
    ?commit : bool -
    ?appendCommit : bool -
    ?stageFile : bool -

Returns: RuntimeOutput

Run GitNet, versioning according to the provided config AutoBumps etc.

Extended Type: GitNetRuntime

?username : string

Git username

?email : string

Git email

?commit : bool

?appendCommit : bool

?stageFile : bool

Returns: RuntimeOutput

this.Run

Full Usage: this.Run

Parameters:
Returns: RuntimeOutput

Remap a gitnet run with the planned bumps and current computed versions of the scopes.

Extended Type: GitNetRuntime

mapping : IDictionary<string, SepochSemver> -> FrozenDictionary<string, GitNetTag voption> -> IDictionary<string, SepochSemver>

A mapping function which provides the bumps to execute; ie, the sepoch semvers to version.

?username : string

Git username

?email : string

Git email

?commit : bool

?appendCommit : bool

?stageFile : bool

Returns: RuntimeOutput

this.TryWriteToOutputAndCommit

Full Usage: this.TryWriteToOutputAndCommit

Parameters:
    content : string - The content to write to the output path

Returns: Result<unit, exn>

Writes the given string to the output path in the GitNetConfig and commits the changes. Returns a Result DU indicating whether the write succeeded or not.

Extended Type: GitNetRuntime

content : string

The content to write to the output path

Returns: Result<unit, exn>

this.TryWriteToOutputAndStage

Full Usage: this.TryWriteToOutputAndStage

Parameters:
    content : string - The content to write to the output path.

Returns: Result<unit, exn>

Writes the given string to the output path in the GitNetConfig and stages the file for committing. Returns a Result DU indicating whether the write succeeded or not.

Extended Type: GitNetRuntime

content : string

The content to write to the output path.

Returns: Result<unit, exn>

this.WriteToOutput

Full Usage: this.WriteToOutput

Parameters:
    content : string - The content to write to the output path

Returns: string

Writes the given string to the output path in the GitNetConfig.

Extended Type: GitNetRuntime

content : string

The content to write to the output path

Returns: string

this.WriteToOutputAndCommit

Full Usage: this.WriteToOutputAndCommit

Parameters:
    content : string - The content to write to the output path.

Writes the given string to the output path in the GitNetConfig and commits the changes. Will fail if the output path is not staged for committing.

Extended Type: GitNetRuntime

content : string

The content to write to the output path.

this.WriteToOutputAndStage

Full Usage: this.WriteToOutputAndStage

Parameters:
    content : string - The content to write to the output path.

Writes the given string to the output path in the GitNetConfig and stages the file for committing.

Pre GitNet 2.0.4, this would never fail. It will not fail if it fails to stage the file for committing. Use TryWriteToOutputAndStage if you want to handle this case with a Result DU.

Extended Type: GitNetRuntime

content : string

The content to write to the output path.

Type something to start searching.