BuildHelpers Module
Nested modules
| Modules | Description |
|
|
|
|
|
Type extensions
| Type extension |
Description
|
Full Usage:
this.RevertVersionProjects
Parameters:
unit
|
Reverts all the
Extended Type:
|
Full Usage:
this.VersionProject
Parameters:
CrackedProject
-
The project to act on.
version : SemVersion
-
The version to apply.
?stageFile : bool
-
Whether to stage the file after writing. Default is false.
?cacheDisposal : bool
-
Whether to cache a reverse function to run on calling the disposal cache functions. Default is true
|
Applies a version to the given project's
Extended Type:
|
Full Usage:
this.VersionProjects
Parameters:
IDictionary<string, SepochSemver>
-
The map of project scopes to versions.
?stageFile : bool
-
Whether to stage the files after writing. Default is false
?cacheDisposal : bool
-
Whether to save the undo action into the Disposal cache. Default is true
|
Applies the given dictionary of scopes and versions to the relevant project
Extended Type:
|
Partas.GitNet