Config Module
Computation Expressions for configuring GitNet
Types and nested modules
| Type/Module | Description |
|
|
|
|
|
|
|
Internal CE use only |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Internal CE use only |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Functions and values
| Function or value |
Description
|
|
Computation Expression to build a
|
|
Computation Expression to build bump mappings for commit messages.
Use the
|
|
|
|
Computation Expression to build a footer key or key value pair.
Used with
|
|
Computation Expression to build a
|
|
Computation Expression to build a GroupMatcher, which is used to determine which commits belong to which group.
|
|
Computation Expression to build a list of IgnoreCommit settings.
Example
1. Skips commits with the [skipci] header.2. Skips commits for the tag v1.0.0. 3. Skips commits with a footer key of "BREAKING CHANGE". |
|
Computation Expression to build bump mappings for major bumps
|
|
Computation Expression to build bump mappings for minor bumps
|
|
Computation Expression to build the
|
|
Computation Expression to build bump mappings for patch bumps
|
|
Computation Expression to build a
|
Partas.GitNet