CommitIgnoreFooterBuilder Type
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
|
|
|
|
Full Usage:
this.Combine
Parameters:
unit
r : CommitIgnoreFooterParts
Returns: CommitIgnoreFooterParts
|
|
Full Usage:
this.Combine
Parameters:
CommitIgnoreFooterParts
r : unit
Returns: CommitIgnoreFooterParts
|
|
Full Usage:
this.Combine
Parameters:
CommitIgnoreFooterValue
r : unit
Returns: CommitIgnoreFooterValue
|
|
Full Usage:
this.Combine
Parameters:
CommitIgnoreFooterKey
r : unit
Returns: CommitIgnoreFooterKey
|
|
Full Usage:
this.Combine
Parameters:
unit
r : CommitIgnoreFooterValue
Returns: CommitIgnoreFooterValue
|
|
Full Usage:
this.Combine
Parameters:
unit
r : CommitIgnoreFooterKey
Returns: CommitIgnoreFooterKey
|
|
Full Usage:
this.Delay
Parameters:
unit -> 'a
Returns: 'a
Modifiers: inline Type parameters: 'a |
|
Full Usage:
this.For
Parameters:
CommitIgnoreFooterValue
value : unit -> CommitIgnoreFooterKey
Returns: CommitIgnoreFooterParts
Modifiers: inline |
|
Full Usage:
this.For
Parameters:
CommitIgnoreFooterKey
value : unit -> CommitIgnoreFooterValue
Returns: CommitIgnoreFooterParts
Modifiers: inline |
|
|
|
|
Ignore commits with the footer key equal to the value
|
Full Usage:
this.Run
Parameters:
CommitIgnoreFooterKey
Returns: IgnoreCommit
Modifiers: inline |
|
Full Usage:
this.Run
Parameters:
CommitIgnoreFooterParts
Returns: IgnoreCommit
Modifiers: inline |
|
Full Usage:
value value
Parameters:
string
Returns: CommitIgnoreFooterParts
Modifiers: inline |
Ignore commits with the footer value equal to the input
|
Full Usage:
value value
Parameters:
string
Returns: CommitIgnoreFooterValue
Modifiers: inline |
Ignore commits with the footer value equal to the input
|
|
|
Full Usage:
this.Yield
Parameters:
unit
|
|
|
|
|
|
|
|
Full Usage:
this.Zero
|
|
Partas.GitNet