FSharpNameResolution Type
Union cases
| Union case |
Description
|
Full Usage:
Auto
|
Title > FileName |
Full Usage:
Directory
|
The directory of a project is used to derive the scope name.
The string mapping to the scope name still utilises the configured method. The default will split
by Example
Scope name: Project
|
Full Usage:
FileName
|
The file name is used to derive the scope name
The string mapping to the scope name still utilises the configured method. The default will split
by Example
Scope name: Project1
|
Full Usage:
Title
|
The title is used to derive the scope name. Projects without a title will be ignored.
The string mapping to the scope name still utilises the configured method. The default will split
by Example
Scope name: Project1
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsAuto
Returns: bool
|
|
Full Usage:
this.IsDirectory
Returns: bool
|
|
Full Usage:
this.IsFileName
Returns: bool
|
|
Full Usage:
this.IsTitle
Returns: bool
|
|
Partas.GitNet