GitNetRuntime Type
Runtime for a GitNetConfig; contains resources that are repeatedly shared between functions. Not intended for side effects. Just to prevent boiler plate parameters being passed around.
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.CommitChanges
Parameters:
string
-
Git username
?email : string
-
Git email
?message : string
-
Message for commit
?date : DateTimeOffset
-
Date
?appendCommit : bool
-
Whether to append to last commit
?writeIndex : bool
-
Whether to write the index before committing. Default true
|
Commits staged files.
Pre GitNet 2.0.4, this would never raise an exception, and would instead log this to console and continue.
This behaviour has been changed to raise an exception. Use
|
|
Tags the current head of the repository with the given semvers. Tags must still be pushed to the repository to have effect.
|
Full Usage:
this.Disposals
Returns: ResizeArray<(unit -> unit)>
|
|
Full Usage:
this.GetAssemblyFileStats
Returns: int
|
|
|
A Run/DryRun computes the versions of scopes from the git history of commits and tags. This computes are cached and can be utilised by users.
|
|
A Run/DryRun computes the versions of scopes from the git history of commits and tags. This computes are cached and can be utilised by users.
|
Full Usage:
this.GetTagStats
Returns: int
|
|
Full Usage:
this.GetVersionFileStats
Returns: int
|
|
Full Usage:
this.StageFiles
Parameters:
string list
-
|
Stages the given files for committing.
Pre GitNet 2.0.4, this would never raise an exception, and would instead log this to console and continue.
This behaviour has been changed to raise an exception. Use
|
Full Usage:
this.TryCommitChanges
Parameters:
string
-
Git username
?email : string
-
Git email
?message : string
-
Message for commit
?date : DateTimeOffset
-
Date
?appendCommit : bool
-
Whether to append to last commit
?writeIndex : bool
-
Whether to write the index before committing. Default true
Returns: Result<unit, exn>
|
Commits staged files. Returns an error if the commit fails.
|
Full Usage:
this.TryCommitTags
Parameters:
SepochSemver seq
-
Returns: Result<SepochSemver, (SepochSemver * exn)> list
|
Tags the current head of the repository with the given semvers. Tags must still be pushed to the repository to have effect.
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.rootDir
Returns: string
|
|
Partas.GitNet