RunExtensions Module
Types
| Type | Description |
|
|
Type extensions
| Type extension |
Description
|
|
|
Full Usage:
this.Run
Parameters:
string
-
Git username
?email : string
-
Git email
?commit : bool
-
?appendCommit : bool
-
?stageFile : bool
-
Returns: RuntimeOutput
|
Run GitNet, versioning according to the provided config AutoBumps etc.
Extended Type:
|
Full Usage:
this.Run
Parameters:
IDictionary<string, SepochSemver> -> FrozenDictionary<string, GitNetTag voption> -> IDictionary<string, SepochSemver>
-
A mapping function which provides the bumps to execute; ie, the sepoch semvers to version.
?username : string
-
Git username
?email : string
-
Git email
?commit : bool
-
?appendCommit : bool
-
?stageFile : bool
-
Returns: RuntimeOutput
|
Remap a gitnet run with the planned bumps and current computed versions of the scopes.
Extended Type:
|
Full Usage:
this.TryWriteToOutputAndCommit
Parameters:
string
-
The content to write to the output path
Returns: Result<unit, exn>
|
Writes the given string to the output path in the
Extended Type:
|
Full Usage:
this.TryWriteToOutputAndStage
Parameters:
string
-
The content to write to the output path.
Returns: Result<unit, exn>
|
Writes the given string to the output path in the
Extended Type:
|
Full Usage:
this.WriteToOutput
Parameters:
string
-
The content to write to the output path
Returns: string
|
Writes the given string to the output path in the
Extended Type:
|
Full Usage:
this.WriteToOutputAndCommit
Parameters:
string
-
The content to write to the output path.
|
Writes the given string to the output path in the
Extended Type:
|
Full Usage:
this.WriteToOutputAndStage
Parameters:
string
-
The content to write to the output path.
|
Writes the given string to the output path in the
Pre GitNet 2.0.4, this would never fail. It will not fail if it fails to stage the file
for committing. Use
Extended Type:
|
Partas.GitNet